@@ -195,8 +195,11 @@ class AtlassianRestAPI(object):
         """
         url = self.url_joiner(None if absolute else self.url, path, trailing)
         params_already_in_url = True if "?" in url else False
-        if (params or flags) and not params_already_in_url:
-            url += "?"
+        if params or flags:
+            if params_already_in_url:
+                url += "&"
+            else:
+                url += "?"
         if params:
             url += urlencode(params or {})
         if flags:
@@ -221,7 +224,7 @@ class AtlassianRestAPI(object):
         response.encoding = "utf-8"
 
         log.debug("HTTP: {} {} -> {} {}".format(method, path, response.status_code, response.reason))
-
+        log.debug("HTTP: Response text -> {}".format(response.text))
         if self.advanced_mode:
             return response
 
