@@ -381,7 +381,7 @@ class ServiceDesk(AtlassianRestAPI):
         """
         Adds users to an organization
         users_list is a list of strings
-        account_list is a list of accountIDs
+        account_list is a list of accountIds
 
         :param organization_id: str
         :param users_list: list
@@ -389,7 +389,7 @@ class ServiceDesk(AtlassianRestAPI):
         """
         log.warning("Adding users...")
         url = "rest/servicedeskapi/organization/{}/user".format(organization_id)
-        data = {"usernames": users_list, "accountIDs": account_list}
+        data = {"usernames": users_list, "accountIds": account_list}
 
         return self.post(url, headers=self.experimental_headers, data=data)
 
@@ -397,7 +397,7 @@ class ServiceDesk(AtlassianRestAPI):
         """
         Removes users from an organization
         users_list is a list of strings
-        account_list is a list of accountIDs
+        account_list is a list of accountIds
 
         :param organization_id: str
         :param users_list: list
@@ -406,7 +406,7 @@ class ServiceDesk(AtlassianRestAPI):
         """
         log.warning("Removing users...")
         url = "rest/servicedeskapi/organization/{}/user".format(organization_id)
-        data = {"usernames": users_list, "accountIDs": account_list}
+        data = {"usernames": users_list, "accountIds": account_list}
 
         return self.delete(url, headers=self.experimental_headers, data=data)
 
@@ -600,7 +600,31 @@ class ServiceDesk(AtlassianRestAPI):
 
         return self.get(url, headers=self.experimental_headers)
 
-    def add_customers(self, service_desk_id, list_of_usernames):
+    def get_customers(self, service_desk_id, query=None, start=0, limit=50):
+        """
+        Returns a list of the customers on a service desk.
+
+        The returned list of customers can be filtered using the query parameter.
+        The parameter is matched against customers' displayName, name, or email.
+        For example, searching for "John", "Jo", "Smi", or "Smith" will match a
+        user with display name "John Smith"..
+
+        :param service_desk_id: str
+        :param list_of_usernames: list
+        :return: the customers added to the service desk
+        """
+        url = "rest/servicedeskapi/servicedesk/{}/customer".format(service_desk_id)
+        params = {}
+        if start is not None:
+            params["start"] = int(start)
+        if limit is not None:
+            params["limit"] = int(limit)
+        if query is not None:
+            params["query"] = query
+
+        return self.get(url, headers=self.experimental_headers, params=params)
+
+    def add_customers(self, service_desk_id, list_of_usernames=[], list_of_accountids=[]):
         """
         Adds one or more existing customers to the given service desk.
         If you need to create a customer, see Create customer method.
@@ -610,13 +634,33 @@ class ServiceDesk(AtlassianRestAPI):
 
         :param service_desk_id: str
         :param list_of_usernames: list
+        :param list_of_accountids: list
         :return: the customers added to the service desk
         """
         url = "rest/servicedeskapi/servicedesk/{}/customer".format(service_desk_id)
-        data = {"usernames": list_of_usernames}
+        data = {"usernames": list_of_usernames, "accountIds": list_of_accountids}
 
+        log.info("Adding customers...")
         return self.post(url, headers=self.experimental_headers, data=data)
 
+    def remove_customers(self, service_desk_id, list_of_usernames=[], list_of_accountids=[]):
+        """
+        Removes one or more customers from a service desk. The service
+        desk must have closed access. If any of the passed customers are
+        not associated with the service desk, no changes will be made for
+        those customers and the resource returns a 204 success code.
+
+        :param service_desk_id: str
+        :param list_of_usernames: list
+        :param list_of_accountids: list
+        :return: the customers added to the service desk
+        """
+        url = "rest/servicedeskapi/servicedesk/{}/customer".format(service_desk_id)
+        data = {"usernames": list_of_usernames, "accountIds": list_of_accountids}
+
+        log.info("Removing customers...")
+        return self.delete(url, headers=self.experimental_headers, data=data)
+
     def get_queues(self, service_desk_id, include_count=False, start=0, limit=50):
         """
         Returns a page of queues defined inside a service desk, for a given service desk ID.
@@ -684,3 +728,30 @@ class ServiceDesk(AtlassianRestAPI):
         ).headers["upm-token"]
         url = "rest/plugins/1.0/?token={upm_token}".format(upm_token=upm_token)
         return self.post(url, files=files, headers=self.no_check_headers)
+
+    def create_request_type(
+        self,
+        service_desk_id,
+        request_type_id,
+        request_name,
+        request_description,
+        request_help_text,
+    ):
+        """
+        Creating a request type
+        :param service_desk_id: str
+        :param request_name: str
+        :param request_description: str
+        :param request_help_test: str
+        """
+        log.warning("Creating request type...")
+        data = {
+            "issueTypeId": request_type_id,
+            "name": request_name,
+            "description": request_description,
+            "helpText": request_help_text,
+        }
+
+        url = "rest/servicedeskapi/servicedesk/{}/requesttype".format(service_desk_id)
+
+        return self.post(url, headers=self.experimental_headers, data=data)
